API Documentation
=================

Atlas
-----

.. automodule:: voxcell.nexus.voxelbrain
   :members:

Traits
------

.. automodule:: voxcell.traits
   :members:

CellCollection
--------------

.. automodule:: voxcell.cell_collection
   :members:

VoxelData
---------

.. automodule:: voxcell.voxel_data
   :members:

Utils
-----

.. automodule:: voxcell.math_utils
   :members:
.. automodule:: voxcell.quaternion
   :members:
.. automodule:: voxcell.region_map
   :members:
.. automodule:: voxcell.vector_fields
   :members:

